/*
##### rrmsb_blocks.js, installed by ###Mod Settings Blocks, by Robin Richmond
The purpose of this Include file is to define a "Mod Settings Block" for a mod's mod options.
For now, Mod Settings Block are in genconfig.php. I am working toward moving them to a separate file.
See the TNG Wiki article 
https://tng.lythgoes.net/wiki/index.php?title=Mod_Settings_Blocks
and/or the file ModSettingsBlocks.docx in the mod subfolder

############################################################
############ document.ready function #######################
This function can be invoked in (almost) any Admin>>Setup program. 
It reorganizes the "source" Mod Settings Blocks so that, in they end.
1. They are inside an HTML layout table that lays the mod options (i.e. form fields)
   for an Admin>>Setup program's subform, or, for programs without a subform, the main
   HTML form layout table.
2. They are sorted by mod name.
3. They are placed inside a new row in the layout table
   Note that layout table rows usually contain a single form field, but with Mod Settings
   Blocks, each row contains a table that contains all of the settings for one mod.
4. Each layout table row actually contains a bordered div that contains:
   a. The mod name as a heading,
   b. A link to the mod's Wiki article,
    c. The mod's Mod Settings Block.

This mod added code to admin_genconf.php that assigned the language string for
"Mod Settings Blocks" to the global Javascript variable rrmsbNewFormLabel.
****************************************************************/

//The ID of the div that contains the contents of the "Mod Settings Blocks" subform.
//It is used in 3 of the functions below
subformID = 'robin13';
//////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////
$(function() {
	var modsCount = $('.rrmsbConfigTable').length;
	if (!modsCount) {
			//Hide banner when a QS param says we are in a popup
			var rrmsbPopup = rrmsbGetQueryStringParam('rrmsbPopup');
			if (rrmsbPopup) {
			$(".topbanner,#leftmenu").hide();
			$("#maincontent").css("padding","0");
		}
		return false; ///Early return; there must be no mods to do///
	}
	var modToOpen = rrmsbGetQueryStringParam('mod');
	var modsCountDisplay;
	if (modsCount>1)
		modsCountDisplay = " &ensp; (" + modsCount + " mods) ";
	else modCountDisplay = '';

	//Create a new subform (a new table row) for the set of mod settings blocks.
	//The new subform follows the last native subform. But it's not the last row in
	//the table because the submit buttons have their own row
	var html = "<tr class='databack tngshadow'><td class='tngshadow'>";
	html += "<span class='subhead'><a href='#' onclick='return rrmsbToggleModSettingsForm();' class='togglehead' style='color:black'>";
	html += "<img src='img/tng_expand.gif' title='toggle display' alt='toggle display' width='15' height='15' border='0' id='plusrr'>";
	html += "<strong class='th-indent'>" + rrmsbNewFormLabel + "</strong></a></span>";
	html += modsCountDisplay + " <span id='listOfModnames'></span><br />";
	html += "<div id='" + subformID + "' xstyle='display:none'><br>";
	html += "<table class='normal'><tbody id='TB" +subformID +"'></tbody></table></div>";
	html += "</td></tr>";
	$("#misc").closest('tr').after(html);

	//Sort the options tables that mods have created.
	var rrGroupList = Array();
	var rrGroupsMods = Array();
	var rrMods = Array();
	var rrModOptions = Array();
	$('.rrmsbConfigTable').each(function() {
		var modname = $(this).attr('modname');
		if (modname == "Mod Settings Blocks")
			modname = ' ' + modname; //Force MSB's MSB to be first
		rrMods.push(modname);
		rrModOptions[modname] = $(this);
		$(this).remove();
	});
	rrMods.sort(); //Sort by modname

	//Put each mod into the subform
	modsCount = rrMods.length;
	var listOfModnames = '';
	for (rr=0; rr<modsCount; rr++) {
		var modname = rrMods[rr];
		var modid = modname.replace(/ /g, '');
		var group = rrModOptions[modname].attr('group');
		//listOfModnames += "(listOfModnames ? ", &emsp " : "") + modname;
		listOfModnames +=  "<div style='display:inline-block;width:10em;'>" + modname + "</div>";
/* not yet
		if (!group) group = 'Misc';
		if ( typeOf rrGroupList[group] === "undefined") {
			rrGroupList[group] = 1;
			rrGrouspMod[group] = Array();
		}
		++rrGroupList[group];
		rrGroupsMods[group][modname] = 1;
*/
		html = "<tr tabindex='-1' id='" +modid+ "' class='rrModOptions' style='display:none;'>" +
			"<td colspan='5' class='normal'>" +
			"<div class='rrmsbModWrapper'>" +
			"<b style='font-size:110%;'>" + modname + "</b> &nbsp;" +
			"<a href='#' onclick=\"return rrmsbOpenWikiPage('" +modname+ "', 'Mod_Options');\">" +
			"<img src='img/rrmsb_wiki.gif' border='2' style='height:16px;width:16px;' class='nw rrmsbWikiButton'></a>" +
			"<table class='rrmsbModTable normal'>" + rrModOptions[modname].html() + "</table>" +
			"</div></td></tr>";

		//Each mod's content is put a new table row at the end of the MSB subform.
		$("#TB" + subformID).append(html);
	} //Loop through mods to create the mod settings blocks	
//Don't display the list of modnames - yet	$("#listOfModnames").html(listOfModnames);
	//If there is a mod to show, show just this one.
	if (modToOpen) {
		$('#'+subformID).show();
		$("#"+modToOpen).show();
		$('#'+modToOpen).focus();
		//Create a form field that should keep the Admin nav bars hidden for a while
		$("form[name='form1']").append("<input type='hidden' name='rrmsbPopup' value='1'>");
	} //end if open a specific MSB
	//Hide banner when a QS param says we are in a popup
	var rrmsbPopup = rrmsbGetQueryStringParam('rrmsbPopup');
	if (rrmsbPopup) {
		$(".topbanner,#leftmenu").hide();
		$("#maincontent").css("padding","0");
	}
}); //end document.ready function

//////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////
//Function to toggle the display of the subform for Mod Settings Blocks.
//It is different from the generic toggleSection function because each
//mod in the subform must be opened the first time the subform is opened.
function rrmsbToggleModSettingsForm() {
	if ($('#plusrr').attr('src')=='img/tng_expand.gif') {
		//Opening the subform. Each mod must be opened, too.
		$('#'+subformID+'').show();
		$('#plusrr').attr('src', 'img/tng_collapse.gif');
		$('.rrModOptions').show(); //Show each mod
	} else { //Closing the subform 	
		//There is no need to hide each mod
		$('#'+subformID+'').hide();
		$('#plusrr').attr('src', 'img/tng_expand.gif');
	}
	return false;
} //end function rrmsbToggleModSettingsForm

//////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////
//Gets the value of a querystring parameter (duh!)
function rrmsbGetQueryStringParam(sParam) {
	var sPageURL = window.location.search.substring(1);
	var sURLVariables = sPageURL.split('&');
	for (var i = 0; i < sURLVariables.length; i++) {
		var sParameterName = sURLVariables[i].split('=');
		if (sParameterName[0] == sParam)
			return sParameterName[1];
	}
	return '';
} //end function rrmsbGetQueryStringParam


//////////////////////////////////////////////////
//function rrModOptionsOpenWikiPage opens a TNG Wiki page as a popup.
//It is invoked by the Wikipedia icon next the mod name that serves as a heading
//for that mod's options.
function rrmsbOpenWikiPage(article, anchor='') {
	newwindow = window.open('https://tng.lythgoes.net/wiki/index.php?title='+article+'#'+anchor, 'wikiwindow', 'height=600, width=780, top=50, left=100, resizable=yes, scrollbars=yes, status=yes');
	newwindow.focus();
	return false;
} //end function rrmsbOpenWikiPage

